/**** datasetup.do: Analysis File for Dynamic Inconistency in Food Choice  ****/
/**** Sadoff et al. (2019) ***/
/*** This file prepares the data for analysis and is called by doanalysis.do ***/

use "Data Files/dataset.dta"

/*** BEGIN DATA SETUP *****/


/* Observation Number */
sort id round immediate food
bysort id : gen obsnum = _n

/* Uniqid */
capture drop uniqid 
egen uniqid = group(id chicago)

capture drop id
gen id = uniqid

/* Uniqidround */
capture drop uniqidround
egen uniqidround = group(uniqid round)

/* Uniqidroundimm */
capture drop uniqidroundimm
egen uniqidroundimm = group(uniqid round immediate)


/* Number of Unique Goods Chosen */
capture drop temp
gen temp = (numchosen != 0)
egen uniqueitem = total(temp), by(id round immediate)

/* Total Number of Goods Chosen */
egen totalchosen = total(numchosen), by(id round immediate)

/* Proportion Unique */
capture drop propunique
gen propunique = uniqueitem/totalchosen

/* Healthy List */
capture drop healthy
gen healthy = 0
replace healthy = 1 if food == "bananas"
replace healthy = 1 if food == "cucumber"
replace healthy = 1 if food == "granny smith apples"
replace healthy = 1 if food == "green peppers"  
replace healthy = 1 if food == "oranges"  
replace healthy = 1 if food == "pears"
replace healthy = 1 if food == "plums"
replace healthy = 1 if food == "red delicious apples"
replace healthy = 1 if food == "red peppers"
replace healthy = 1 if food == "tomato"
replace healthy = 1 if food == "baby carrots"
replace healthy = 1 if food == "bananas"    
replace healthy = 1 if food == "cucumbers"
replace healthy = 1 if food == "diced tomatoes"   
replace healthy = 1 if food == "gala apples"   
replace healthy = 1 if food == "garden salad"  
replace healthy = 1 if food == "green apples"    
replace healthy = 1 if food == "oranges"      
replace healthy = 1 if food == "peach cup"
replace healthy = 1 if food == "red grapes"                      
                       
/* Salty Snack */					   
capture drop saltysnack 
gen saltysnack = 0
replace saltysnack = 1 if food == "cheetos"
replace saltysnack = 1 if food == "cheez-its"		
replace saltysnack = 1 if food == "doritos"
replace saltysnack = 1 if food == "doritos nacho cheese"								   
replace saltysnack = 1 if food == "lays potato chips"
replace saltysnack = 1 if food == "takis"	
replace saltysnack = 1 if food == "tortilla chips"	

/* Sweet Snack */
capture drop sweetsnack 
gen sweetsnack = 0
replace sweetsnack = 1 if saltysnack == 0 & healthy == 0						   

						   
/* Perishable */		   
capture drop perishable
gen perishable = 0
replace perishable = 1 if  (healthy == 1 | chicago == 0)
replace perishable = 0 if food == "diced tomatoes"
replace perishable = 0 if food == "peach cup"
replace perishable = 0 if food == "takis"
replace perishable = 0 if food == "doritos"

       
/* Chosen Dummy */
capture drop ischosen
gen ischosen = (numchosen>0)
replace ischosen = ischosen + 1


/* Rating Data */
destring rating, force replace

/* Commit Data*/
destring commit, force replace

/* Commit LA Week 2 Data*/
destring law2commit, force replace


/* Commitment Available */
gen commitavail = 0
replace commitavail = 1 if round == 2 & chicago == 1
replace commitavail = 1 if round == 2 & law2commit != . & chicago == 0
replace commitavail = 1 if round == 3 & chicago == 0 

/* Comitted at Relevant Time Point */
gen commit_round = .
replace commit_round = 0 if commitavail==1
replace commit_round = 1 if commitavail==1 & commit == 1 & chicago == 1
replace commit_round = 1 if commitavail == 1 & round == 2 & law2commit == 1 & chicago == 0
replace commit_round = 1 if commitavail==1 & commit == 1 & round == 3 & chicago == 0 

/* Ever Commit */
gen evercommit = 0
replace evercommit = 1 if commit == 1 | law2commit == 1

/* Commit First Offer */
gen commitfirst = 0
replace commitfirst = 1 if commit ==1 & chicago == 1
replace commitfirst = 1 if law2commit == 1
replace commitfirst = 1 if law2commit == . & commit == 1 & chicago == 0



/* Nutritional Information */
local nutrition "cal fat satfat carb fiber protein sugar addsugar"

gen totalsugar = sugar+addsugar
gen nonsatfat = fat-satfat
gen residcarb = carb-sugar-addsugar-fiber

/* Aggregate Nutrition Values */
capture drop temp
gen temp = numchosen*cal
egen bundlecal = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*fat
egen bundlefat = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*satfat
egen bundlesatfat = total(temp), by(id round immediate)


capture drop temp
gen temp = numchosen*carb
egen bundlecarb = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*fiber
egen bundlefiber = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*sugar
egen bundlesugar = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*addsugar
egen bundleaddsugar = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*totalsugar
egen bundletotalsugar = total(temp), by(id round immediate)


capture drop temp
gen temp = numchosen*protein
egen bundleprotein = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*healthy
egen bundlehealthy = total(temp), by(id round immediate)

capture drop prophealthy
gen prophealthy = bundlehealthy/totalchosen

capture drop temp
gen temp = numchosen*saltysnack
egen bundlesaltysnack = total(temp), by(id round immediate)

capture drop temp
gen temp = numchosen*sweetsnack
egen bundlesweetsnack = total(temp), by(id round immediate)


/* Inconsistencies */
capture drop temp
gen temp = inconsistent if round == 1
egen inconsistentr1 = mean(temp),by(uniqid)

capture drop temp
gen temp = inconsistent if round == 2 & commitavail == 0
egen inconsistentr2 = mean(temp),by(uniqid)


capture drop temp
gen temp = inconsistent if (round == 2 & chicago == 1) | (round == 3 & chicago ==0)
egen inconsistentfinal = mean(temp),by(uniqid)

capture drop temp
gen temp = inconsistent if commitavail == 0
egen inconsistentnocommit = mean(temp),by(uniqid)
replace inconsistentnocommit = 1 if inconsistentnocommit == 0.5

capture drop temp
gen temp = inconsistent if commitavail == 1
egen inconsistentcommit = mean(temp),by(uniqid)
replace inconsistentcommit = 1 if inconsistentcommit == 0.5



gen countdifferencetop = countdifference
replace countdifferencetop = -1 if countdifference <-1 & countdifference != .
replace countdifferencetop = 1 if countdifference >1 & countdifference != .

capture drop temp
gen temp = countdifferencetop if round == 1
egen countdifferencer1 = mean(temp),by(uniqid)

capture drop temp
gen temp = countdifferencetop if round == 2 & commitavail == 0
egen countdifferencer2 = mean(temp),by(uniqid)


capture drop temp
gen temp = countdifferencetop if commitavail == 0
egen countdifferencenocommit = mean(temp),by(uniqid)

capture drop temp
gen temp = countdifferencetop if commitavail == 1
egen countdifferencecommit = mean(temp),by(uniqid)


capture drop temp
gen temp = bundlecal if immediate == 0 
capture drop bundlecaladv
egen bundlecaladv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = bundlecal if immediate == 1 
capture drop bundlecalimm
egen bundlecalimm = mean(temp3), by(uniqid round)
capture drop bundlecaldiff
gen bundlecaldiff = bundlecalimm-bundlecaladv

capture drop temp
gen temp = bundlecaldiff if round == 1
capture drop bundlecaldiffr1
egen bundlecaldiffr1 = mean(temp),by(uniqid)

capture drop temp
gen temp = bundlecaldiff if round == 2 & commitavail == 0
capture drop bundlecaldiffr2
egen bundlecaldiffr2 = mean(temp),by(uniqid)

capture drop temp
gen temp = prophealthy if immediate == 0 
capture drop prophealthyadv
egen prophealthyadv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = prophealthy if immediate == 1 
capture drop prophealthyimm
egen prophealthyimm = mean(temp3), by(uniqid round)
capture drop prophealthydiff
gen prophealthydiff = prophealthyimm-prophealthyadv

capture drop temp
gen temp = bundlehealthy if immediate == 0 
capture drop bundlehealthyadv
egen bundlehealthyadv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = bundlehealthy if immediate == 1 
capture drop bundlehealthyimm
egen bundlehealthyimm = mean(temp3), by(uniqid round)
capture drop bundlehealthydiff
gen bundlehealthydiff = bundlehealthyimm-bundlehealthyadv


capture drop temp
gen temp = bundlefat if immediate == 0 
capture drop bundlefatadv
egen bundlefatadv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = bundlefat if immediate == 1 
capture drop bundlefatimm
egen bundlefatimm = mean(temp3), by(uniqid round)


capture drop temp
gen temp = bundlecarb if immediate == 0 
capture drop bundlecarbadv
egen bundlecarbadv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = bundlecarb if immediate == 1 
capture drop bundlecarbimm
egen bundlecarbimm = mean(temp3), by(uniqid round)



capture drop temp
gen temp = bundleprotein if immediate == 0 
capture drop bundleproteinadv
egen bundleproteinadv = mean(temp), by(uniqid round)
capture drop temp3
gen temp3 = bundleprotein if immediate == 1 
capture drop bundleproteinimm
egen bundleproteinimm = mean(temp3), by(uniqid round)




/* Chosen Rating Values */
capture drop maxrating
egen maxrating = max(rating), by(id)

capture drop temp
gen temp = numchosen*rating

capture drop bundlerating =
egen bundlerating = total(temp), by(id round immediate)

capture drop proppotentialrating
gen proppotentialrating = bundlerating/(maxrating*totalchosen)

capture drop temp
gen temp = (rating != .) if round == 1 & immediate == 0
capture drop numrating
egen numrating = total(temp), by(id)


capture drop normrating
gen normrating = rating/maxrating


/* Should Rating */
destring should, force replace


/* Prior Choice */
capture drop temp
gen temp = numchosen  if immediate == 0 
capture drop numwaschosen
egen numwaschosen = mean(temp), by(uniqid round food)
replace numwaschosen = . if immediate == 0

capture drop temp
gen temp = ischosen  if immediate == 0 
capture drop waschosen
egen waschosen = mean(temp), by(uniqid round food)
replace waschosen = . if immediate == 0


/* Unambiguous Choice Relation */
capture drop temp
gen temp = abs(ischosen - waschosen)

gen ischosen_unambig = ischosen
replace ischosen_unambig = . if immediate == 0
replace ischosen_unambig = . if temp == 1

capture drop temp
gen temp = abs(numchosen - numwaschosen)

capture drop totalexchanges
egen totalexchanges = total(temp), by(uniqid round)
replace totalexchanges = totalexchanges/2

capture drop temp
egen temp = rowmin(numchosen numwaschosen)
replace temp = . if immediate == 0

capture drop totalchosen_unambig 
egen totalchosen_unambig = total(temp), by(uniqid round)

capture drop temp2
gen temp2 = temp*healthy
egen bundlehealthy_unambig = total(temp2), by(uniqidround)

capture drop prophealthy_unambig 
gen prophealthy_unambig = bundlehealthy_unambig/totalchosen_unambig


/* Demographic Characteristics */
/* Age */
destring(age), force replace
replace age = . if age > 100 | age < 0
/* Gender */
gen male = .
replace male = 0 if female == "1" | female == "F"
replace male = 1 if female == "2" | female == "M"
/* Income */
gen hhinc = .
replace hhinc = 5 if income == "0 to 5000" 
replace hhinc = 15 if income == "6000 to 15000"
replace hhinc = 25 if income == "16000 to 25000"
replace hhinc = 35 if  income == "26000 to 35000"
replace hhinc = 45 if income == "36000 to 45000"
/* Household Size */
destring(numadults), force replace
destring(numchildren), force replace
gen hhsize = numadults+numchildren

/* More Kids at Delivery */
gen nokids = (numchildren == 0) 
replace nokids = . if numchildren == .



/* SNAP */
gen snapenrolled = 0
replace snapenrolled = 1 if snap == "1"

/* Remaining SNAP Funds at Registration */
destring(registrationsnapavail), force replace

/* Remaining SNAP Funds at DElivery */
destring(delivery1snapavail), force replace

capture drop lesssnap
gen lesssnap = (delivery1snapavail < registrationsnapavail)
replace lesssnap = . if (delivery1snapavail ==. |  registrationsnapavail == .)


/* Registration Hungry */
capture drop hungryatreg
gen hungryatreg = .
replace hungryatreg = 1 if registrationhungry == "a" 
replace hungryatreg = 0 if   registrationhungry == "b" | registrationhungry == "c" |  registrationhungry == "d" 

/* Delivery Hungry */
capture drop hungryatdel
gen hungryatdel = .
replace hungryatdel = 1 if delivery1hungry == "a" 
replace hungryatdel = 0 if   delivery1hungry == "b" | delivery1hungry == "c" |  delivery1hungry == "d" 

capture drop morehungry
gen morehungry = (hungryatreg < hungryatdel)
replace morehungry = . if hungryatreg == . | hungryatdel == .


/* Food Insecurity Score at Registration */
capture drop foodinsecureatreg 
gen foodinsecureatreg = .
replace foodinsecureatreg = 0 if registrationfoodsec1 != "NA"
replace foodinsecureatreg = 1 if registrationfoodsec1 == "O" | registrationfoodsec1 == "a"
replace foodinsecureatreg = foodinsecureatreg + 1 if registrationfoodsec2 == "O" | registrationfoodsec2 == "a"
replace foodinsecureatreg = foodinsecureatreg + 1 if registrationfoodsec3 == "Y" | registrationfoodsec3 == "y"
replace foodinsecureatreg = foodinsecureatreg + 1 if registrationfoodsec4 == "Y" | registrationfoodsec4 == "y"
replace foodinsecureatreg = foodinsecureatreg + 1 if registrationfoodsec5 == "Y" | registrationfoodsec5 == "y"
replace foodinsecureatreg = foodinsecureatreg + 1 if registrationfoodsec6 == "Y" | registrationfoodsec6 == "y"


/* Food Insecurity Score at Delivery */
capture drop foodinsecureatdel 
gen foodinsecureatdel = .
replace foodinsecureatdel = 0 if delivery1foodsec1 != "NA"
replace foodinsecureatdel = 1 if delivery1foodsec1 == "O" | delivery1foodsec1 == "a"
replace foodinsecureatdel = foodinsecureatdel + 1 if delivery1foodsec2 == "O" | delivery1foodsec2 == "a"
replace foodinsecureatdel = foodinsecureatdel + 1 if delivery1foodsec3 == "Y" | delivery1foodsec3 == "y"
replace foodinsecureatdel = foodinsecureatdel + 1 if delivery1foodsec4 == "Y" | delivery1foodsec4 == "y"
replace foodinsecureatdel = foodinsecureatdel + 1 if delivery1foodsec5 == "Y" | delivery1foodsec5 == "y"
replace foodinsecureatdel = foodinsecureatdel + 1 if delivery1foodsec6 == "Y" | delivery1foodsec6 == "y"


capture drop moreinsecure
gen moreinsecure = (foodinsecureatdel > foodinsecureatreg)
replace moreinsecure = . if (foodinsecureatdel == . | foodinsecureatreg == . )

/* Registration Children Present */
destring registrationchildren, force replace
replace registrationchildren = 0 if registrationchildren == . & chicago ==  0


/* Delivery Children Present */
destring delivery1children, force replace
replace delivery1children = 0 if delivery1children == . & chicago ==  0


/* More Kids at Delivery */
gen morekids = (registrationchildren < delivery1children) 
replace morekids = . if delivery1children == . | registrationchildren == .



/*** BEGIN INDIVIDUAL LEVEL ESTIMATES FOR LATER USE ****/

/* Unambiguous Evaluation */
capture drop bundlevali_un
gen bundlevali_un = .

capture drop ranki_un
gen ranki_un = .

capture drop chi2i_un
gen chi2i_un = .

capture drop bestvaluei_un
gen bestvaluei_un = .

forvalues i = 1(1)1006  {
qui capture rologit ischosen_unambig  healthy fat carb protein  if immediate == 1 & commitavail == 0 & uniqidround == `i', group(uniqidround) ties(efron)
qui capture drop goodvaluei_un 
qui capture predict goodvaluei_un if uniqidround == `i',  xb
qui capture drop temp
qui capture egen temp = max(goodvaluei_un) if uniqidround == `i'
qui capture replace bestvaluei_un = temp if uniqidround == `i'
qui capture drop temp
qui capture gen temp = goodvaluei_un*numchosen if uniqidround == `i' 
qui capture drop temp2
qui capture egen temp2 = total(temp) if uniqidround == `i', by(immediate)
qui capture replace bundlevali_un = temp2 if uniqidround == `i' 
qui capture replace ranki_un = e(rank) if uniqidround == `i' 
qui capture replace chi2i_un = e(chi2) if uniqidround == `i' 
qui capture ereturn clear
disp `i'
}



capture drop temp
gen temp = bundlevali_un 
replace temp = . if immediate == 1
capture drop bundlevali_adv_un
egen bundlevali_adv_un = mean(temp), by(uniqid round)

capture drop temp
gen temp = bundlevali_un 
replace temp = . if immediate == 0
capture drop bundlevali_imm_un
egen bundlevali_imm_un = mean(temp), by(uniqid round)

capture drop bundlediffi_un
gen bundlediffi_un =  bundlevali_imm_un  - bundlevali_adv_un

capture drop bundlediffiperc_un
gen bundlediffiperc_un =  (bundlevali_adv_un  - bundlevali_imm_un)/abs(bundlevali_adv_un)
replace bundlediffiperc_un = 1 if bundlediffiperc_un >1 & bundlediffiperc_un != .
replace bundlediffiperc_un = -1 if bundlediffiperc_un <-1 & bundlediffiperc_un != .
replace bundlediffiperc_un = 0 if inconsistent == 0 

capture drop bundlediffibest_un
gen bundlediffibest_un =  (bundlevali_adv_un  - bundlevali_imm_un)/bestvaluei_un
replace bundlediffibest_un = 10 if bundlediffibest_un > 10 & bundlediffibest_un != .
replace bundlediffibest_un = -10 if bundlediffibest_un <-10 & bundlediffibest_un != .
replace bundlediffibest_un = 0 if inconsistent == 0 


capture drop bundlediffidum_un
gen bundlediffidum_un =  bundlediffi_un
replace bundlediffidum_un = -1 if bundlediffi_un > 0 & bundlediffi_un != .
replace bundlediffidum_un= 1 if  bundlediffi_un < 0 & bundlediffi_un != .


capture drop tailorcommit
gen tailorcommit = 0
replace tailorcommit = 1 if bundlediffidum_un == 1



/* Advanced Evaluation */
capture drop bundlevali_adv
gen bundlevali_adv = .

capture drop ranki_adv
gen ranki_adv = .

capture drop chi2i_adv
gen chi2i_adv = .


capture drop bestvaluei_adv
gen bestvaluei_adv = .


forvalues i = 1(1)1006  {
qui capture rologit ischosen  healthy fat carb protein  if immediate == 0 & commitavail == 0 & uniqidround == `i', group(uniqidround) ties(efron)
qui capture drop goodvaluei_adv
qui capture predict goodvaluei_adv if uniqidround == `i',  xb
qui capture drop temp
qui capture egen temp = max(goodvaluei_adv) if uniqidround == `i'
qui capture replace bestvaluei_adv = temp if uniqidround == `i'
qui capture drop temp
qui capture gen temp = goodvaluei_adv*numchosen if uniqidround == `i' 
qui capture drop temp2
qui capture egen temp2 = total(temp) if uniqidround == `i', by(immediate)
qui capture replace bundlevali_adv = temp2 if uniqidround == `i' 
qui capture replace ranki_adv = e(rank) if uniqidround == `i' 
qui capture replace chi2i_adv = e(chi2) if uniqidround == `i' 
qui capture ereturn clear
disp `i'
}




capture drop temp
gen temp = bundlevali_adv
replace temp = . if immediate == 1
capture drop bundlevali_adv_adv
egen bundlevali_adv_adv = mean(temp), by(uniqid round)

capture drop temp
gen temp = bundlevali_adv
replace temp = . if immediate == 0
capture drop bundlevali_imm_adv
egen bundlevali_imm_adv = mean(temp), by(uniqid round)

capture drop bundlediffi_adv
gen bundlediffi_adv =  bundlevali_imm_adv  - bundlevali_adv_adv

capture drop bundlediffiperc_adv
gen bundlediffiperc_adv =  (bundlevali_adv_adv  - bundlevali_imm_adv)/abs(bundlevali_adv_adv)
replace bundlediffiperc_adv = 1 if bundlediffiperc_adv >1 & bundlediffiperc_adv != .
replace bundlediffiperc_adv = -1 if bundlediffiperc_adv <-1 & bundlediffiperc_adv != .
replace bundlediffiperc_adv = 0 if inconsistent == 0 


capture drop bundlediffibest_adv
gen bundlediffibest_adv =  (bundlevali_adv_adv  - bundlevali_imm_adv)/bestvaluei_adv
replace bundlediffibest_adv = 10 if bundlediffibest_adv > 10 & bundlediffibest_adv != .
replace bundlediffibest_adv = -10 if bundlediffibest_adv <-10 & bundlediffibest_adv != .
replace bundlediffibest_adv = 0 if inconsistent == 0 



capture drop bundlediffidum_adv
gen bundlediffidum_adv =  bundlediffi_adv
replace bundlediffidum_adv = -1 if bundlediffi_adv > 0 & bundlediffi_adv != .
replace bundlediffidum_adv= 1 if bundlediffi_adv < 0  & bundlediffi_adv != .


/* Immediate Evaluation */
capture drop bundlevali_imm
gen bundlevali_imm = .


capture drop ranki_imm
gen ranki_imm = .

capture drop chi2i_imm
gen chi2i_imm = .


capture drop bestvaluei_imm
gen bestvaluei_imm = .


forvalues i = 1(1)1006  {
qui capture rologit ischosen  healthy fat carb protein  if immediate == 1 & commitavail == 0 & uniqidround == `i', group(uniqidround) ties(efron)
qui capture drop goodvaluei_imm
qui capture predict goodvaluei_imm if uniqidround == `i',  xb
qui capture drop temp
qui capture egen temp = max(goodvaluei_imm) if uniqidround == `i'
qui capture replace bestvaluei_imm = temp if uniqidround == `i'
qui capture drop temp
qui capture gen temp = goodvaluei_imm*numchosen if uniqidround == `i' 
qui capture drop temp2
qui capture egen temp2 = total(temp) if uniqidround == `i', by(immediate)
qui capture replace bundlevali_imm = temp2 if uniqidround == `i' 
qui capture replace ranki_imm = e(rank) if uniqidround == `i' 
qui capture replace chi2i_imm = e(chi2) if uniqidround == `i' 
qui capture ereturn clear
disp `i'
}



capture drop temp
gen temp = bundlevali_imm
replace temp = . if immediate == 1
capture drop bundlevali_adv_imm
egen bundlevali_adv_imm = mean(temp), by(uniqid round)

capture drop temp
gen temp = bundlevali_imm
replace temp = . if immediate == 0
capture drop bundlevali_imm_imm
egen bundlevali_imm_imm = mean(temp), by(uniqid round)

capture drop bundlediffi_imm
gen bundlediffi_imm =  bundlevali_imm_imm  - bundlevali_adv_imm

capture drop bundlediffiperc_imm
gen bundlediffiperc_imm =  (bundlevali_adv_imm  - bundlevali_imm_imm)/abs(bundlevali_adv_imm)
replace bundlediffiperc_imm = 1 if bundlediffiperc_imm >1 & bundlediffiperc_imm != .
replace bundlediffiperc_imm = -1 if bundlediffiperc_imm <-1 & bundlediffiperc_imm != .
replace bundlediffiperc_imm = 0 if inconsistent == 0 


capture drop bundlediffibest_imm
gen bundlediffibest_imm =  (bundlevali_adv_imm  - bundlevali_imm_imm)/bestvaluei_imm
replace bundlediffibest_imm = 10 if bundlediffibest_imm > 10 & bundlediffibest_imm != .
replace bundlediffibest_imm = -10 if bundlediffibest_imm <-10 & bundlediffibest_imm != .
replace bundlediffibest_imm = 0 if inconsistent == 0 


capture drop bundlediffidum_imm
gen bundlediffidum_imm =  bundlediffi_imm
replace bundlediffidum_imm = -1 if bundlediffi_imm>0 & bundlediffi_imm != .
replace bundlediffidum_imm = 1 if bundlediffi_imm < 0  & bundlediffiperc_imm != .



/* Measures for Evaluation of Commitment Policy */
capture drop temp
gen temp = bundlediffiperc_adv  if commitavail == 0 
capture drop VAq
egen VAq = mean(temp), by(uniqid)

capture drop temp
gen temp = bundlediffiperc_adv  if (round == 2 & chicago == 1 ) | (round== 3 & chicago == 0)
capture drop VAqC
egen VAqC = mean(temp), by(uniqid)

capture drop VAdiff
gen VAdiff = VAq - VAqC


capture drop temp
gen temp = bundlediffiperc_imm  if commitavail == 0 
capture drop VIq
egen VIq = mean(temp), by(uniqid)

capture drop temp
gen temp = bundlediffiperc_imm  if  (round == 2 & chicago == 1 ) | (round== 3 & chicago == 0)
capture drop VIqC
egen VIqC = mean(temp), by(uniqid)

capture drop VIdiff
gen VIdiff = VIq - VIqC


capture drop temp
gen temp = bundlediffiperc_un if commitavail == 0 
capture drop VUq
egen VUq = mean(temp), by(uniqid)

capture drop temp
gen temp = bundlediffiperc_un  if (round == 2 & chicago == 1 ) | (round== 3 & chicago == 0)
capture drop VUqC
egen VUqC = mean(temp), by(uniqid)

capture drop VUdiff
gen VUdiff = VUq - VUqC

/* Disagreement */
gen disagree = 0
replace disagree = 1 if bundlediffiperc_imm > 0 & bundlediffiperc_adv < 0
replace disagree = 1 if bundlediffiperc_imm < 0 & bundlediffiperc_adv > 0
replace disagree = . if inconsistent == 0


/* Indicator for Tailored Commitment Policy */
/* Commit if Your Unambiguous Preferences Say You Should */
capture drop tailorcommit
gen tailorcommit = 0
replace tailorcommit = 1 if bundlediffidum_un == 1


/**** END INDIVIDUAL LEVEL ESTIMATES  FOR LATER USE ****/

/*** END DATA SETUP *****/
