/**** dofigures.do: Analysis File for Dynamic Inconistency in Food Choice  ****/
/**** Sadoff et al. (2019) ***/
/*** This file generates all figures and logs relevant statistics for the paper and is called by doanalysis.do ***/




/*** BEGIN FIGURE 2 ***/
capture drop meanchosenadv
capture drop temp
capture drop temp2
gen temp = (numchosen>0)
capture drop temp2
egen temp2 = mean(temp) if commitavail == 0 & attrit == 0 & immediate == 0, by(food chicago round)
egen meanchosenadv = mean(temp2), by(food round  chicago)
capture drop meanchosenimm
capture drop temp
capture drop temp2
gen temp = (numchosen>0)
capture drop temp2
egen temp2 = mean(temp) if commitavail == 0 & attrit == 0 & immediate == 1, by(food chicago round)
egen meanchosenimm = mean(temp2), by(food round  chicago)

capture drop meanchosendiff
gen meanchosendiff = meanchosenadv-meanchosenimm

twoway  (scatter meanchosendiff meanchosenadv if  healthy == 0, mcolor(black) msymbol(circle_hollow)) (scatter meanchosendiff meanchosenadv if  healthy == 1, mcolor(black) msymbol(plus))   (scatteri  0 0 0 1 , recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if (uniqid == 1 | uniqid == 170 ) & immediate == 0 & commitavail == 0,   scheme(s1mono) ylabel(-0.1(0.025)0.1) xlabel(0(0.25)1) xtitle("Advance Inclusion Probability") ytitle("Advance-Immediate Inclusion Probability") legend(order(2 "Fruits and Vegetables" 1 "Snacks and Sweets") rows(1))
graph export "behavior3.pdf", replace

/*** END FIGURE 2 ***/


/*** BEGIN FIGURE 3 ***/
capture drop sample
gen sample = 0
replace sample = 1 if commitavail == 0 & (obsnum == 1 | obsnum == 41) & attrit == 0 

capture drop losangeles 
gen losangeles = 1-chicago 

capture drop group
egen group = group(losangeles inconsistent) if sample == 1



xi: reg evercommit i.group, clu(uniqid)
capture drop meancommit
predict meancommit
capture drop meancommitse
predict meancommitse, stdp
capture drop meanhigh 
gen meanhigh = meancommit+1*meancommitse
capture drop meanlow 
gen meanlow = meancommit-1*meancommitse


twoway (bar meancommit group if (uniqid == 2 | uniqid ==3  | uniqid == 75 | uniqid == 69), fcolor(white) lcolor(black) lwidth(medium) barwidth(0.9)) (rcap meanhigh meanlow group if (uniqid == 2 | uniqid ==3  | uniqid == 75 | uniqid == 69), lcolor(black)), ytitle(Fraction Committing) ylabel(0(0.25)1) xtitle("") xlabel(1.5 "Chicago" 3.5 "Los Angeles", labels labgap(medsmall) noticks) xmtick(1 "Consistent"   2 "Inconsistent"   3 "Consistent"  4 "Inconsistent", labels labsize(small)) legend(order( 2 "+/- 1 s.e.") rows(1)) scheme(s1mono)
graph export "inconsistentcommit.pdf", replace


/*** END FIGURE 3 ***/



/*** BEGIN FIGURE 4 ***/
/*** SEE R-CODE ****/
/*** END FIGURE 4 ****/


/*** BEGIN FIGURE 5 ***/
capture drop sample
gen sample = 0
replace sample = 1 if commitavail == 0 & (obsnum == 1 | obsnum == 41) & attrit == 0  &  ///
inconsistent == 1 & bundlediffiperc_adv != . & bundlediffiperc_imm != . & bundlediffiperc_un != .  & ranki_un == 4 & ranki_adv == 4 & ranki_imm == 4 


twoway (histogram bundlediffiperc_imm ,  percent  width(0.05) color(gray)   barwidth(0.04) gap(10)) ///
       (histogram bundlediffiperc_adv,  percent  width(0.05) fcolor(none) barwidth(0.04) gap(10) lcolor(black)) ///
	   (scatteri 0 0 20 0, recast(line) lpattern(dash) lcolor(gray)) /// 
	    if sample == 1, 	   scheme(s1mono) ///
	   legend(order(2 "Advance" 1 "Immediate"  ) row(1))   title(Panel A: Welfare Effects of Inconsistency) xtitle("Welfare Costs")
graph save "panelA.gph", replace   
	   
twoway 		(scatter bundlediffiperc_imm bundlediffiperc_adv, jitter(10)) ///
(lfit bundlediffiperc_imm bundlediffiperc_adv, lcolor(gray) lpattern(solid)) ///
(scatteri -1 -1 1 1, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri -1 0 1 0, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri 0 -1 0 1, recast(line) lpattern(dash) lcolor(gray)) /// 
	   if sample == 1, 	   scheme(s1mono) ///
	   	xtitle(Advance) ytitle(Immediate)    legend(order(2 "Immediate-Advance Fit, Corr = 0.28 (p <0.01)"  ) row(1)) title(Panel B: Advance-Immediate Agreement) 
graph save "panelB.gph", replace  
graph combine "panelA.gph" "panelB.gph", xsize(16) ysize(8) row(1) scheme(s1mono)
graph export "graphwelfare2.pdf", replace

log on
/* Additional Stats for Figures 5 and 6 */

su bundlediffiperc_adv bundlediffiperc_imm bundlediffiperc_un if sample == 1, det
signrank bundlediffiperc_adv =  bundlediffiperc_imm  if sample == 1

corr bundlediffiperc_adv bundlediffiperc_imm bundlediffiperc_un if sample == 1
corr bundlediffidum_adv bundlediffidum_imm bundlediffidum_un if sample == 1
pwcorr bundlediffiperc_adv bundlediffiperc_imm bundlediffiperc_un if sample == 1, sig

tab bundlediffidum_adv if sample == 1
tab bundlediffidum_imm if sample == 1
tab bundlediffidum_adv bundlediffidum_imm if sample == 1
tab bundlediffidum_adv bundlediffidum_imm if sample == 1 & disagree == 1
tab bundlediffidum_adv bundlediffidum_un if sample == 1 & disagree == 0
tab bundlediffidum_un if sample == 1

count if (bundlediffiperc_adv > 0  &  bundlediffiperc_imm < 0) & sample == 1
count if (bundlediffiperc_un >  0 & bundlediffiperc_adv > 0  &  bundlediffiperc_imm < 0) & sample == 1
count if (bundlediffiperc_adv < 0  &  bundlediffiperc_imm > 0) & sample == 1
count if (bundlediffiperc_un <  0 & bundlediffiperc_adv < 0  &  bundlediffiperc_imm > 0) & sample == 1

count if ((bundlediffiperc_adv < 0  &  bundlediffiperc_imm < 0 &  bundlediffiperc_un < 0) | (bundlediffiperc_adv > 0  &  bundlediffiperc_imm > 0 &  bundlediffiperc_un > 0)) & sample == 1
log off

/*** END FIGURE 5 ****/


/*** BEGIN FIGURE 6 ***/
capture drop sample
gen sample = 0
replace sample = 1 if commitavail == 0 & (obsnum == 1 | obsnum == 41) & attrit == 0  &  ///
inconsistent == 1 & bundlediffiperc_adv != . & bundlediffiperc_imm != . & bundlediffiperc_un != .  & ranki_un == 4 & ranki_adv == 4 & ranki_imm == 4 

twoway      (histogram bundlediffiperc_un ,  percent  width(0.05) color(gray)   barwidth(0.04) gap(10)) ///
	   (scatteri 0 0 20 0, recast(line) lpattern(dash) lcolor(gray)) /// 
	    if sample == 1, 	   scheme(s1mono) ///
	   legend(off)   title(Panel A: Unambiguous Welfare Measure) xtitle("Welfare Costs")
graph save "panelA.gph", replace   

twoway 		(scatter bundlediffiperc_imm bundlediffiperc_un, jitter(10)) ////
(scatter bundlediffiperc_adv bundlediffiperc_un, jitter(10) msymbol(circle_hollow) mcolor(black)) ///
(lfit bundlediffiperc_imm bundlediffiperc_un, lcolor(gray) lpattern(solid)) ///
(lfit bundlediffiperc_adv bundlediffiperc_un, lcolor(black) lpattern(solid)) ///
(scatteri -1 -1 1 1, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri -1 0 1 0, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri 0 -1 0 1, recast(line) lpattern(dash) lcolor(gray)) /// 
if sample == 1, 	   scheme(s1mono) ///
	    	   legend(order(2 "Advance"  4 "Adv-Unambig Fit, Corr = 0.54 (p < 0.01)" 1 "Immediate" 3 "Imm-Unambig Fit, Corr = 0.63 (p < 0.01)"  ) row(2)) ytitle("Advance or Immediate") xtitle(Unambiguous)  title(Panel B: Agreement with Unambiguous) 
			  graph save "panelB.gph", replace  
graph combine "panelA.gph" "panelB.gph", xsize(16) ysize(8) row(1) scheme(s1mono)
graph export "graphwelfare3.pdf", replace 
			   

/*** END FIGURE 6 ****/
			   
/*** BEGIN FIGURE 7 ***/
/* Panel A: Offered Commitment */
capture drop sample
gen sample = 0
replace sample = 1 if commitavail == 0 & (obsnum == 1 | obsnum == 41) & attrit == 0  &  ///
 bundlediffiperc_adv != . & bundlediffiperc_imm != . & bundlediffiperc_un != .  & ranki_un == 4 & ranki_adv == 4 & ranki_imm == 4 



capture drop temp
gen temp = 5
replace temp = 9 if bundlediffidum_adv == 1 & evercommit == 1
replace temp = 1 if bundlediffidum_adv == -1  & evercommit == 1
replace temp = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)

capture drop temp2
gen temp2 = 6
replace temp2 = 10 if bundlediffidum_imm == 1 & evercommit == 1
replace temp2 = 2 if bundlediffidum_imm == -1 & evercommit == 1
replace temp2 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0& sample == 1 )


capture drop temp3
gen temp3 = 7
replace temp3 = 11 if bundlediffidum_un == 1 & evercommit == 1
replace temp3 = 3 if bundlediffidum_un == -1 & evercommit == 1
replace temp3 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)



twoway (histogram temp , discrete  percent width(1) fcolor(none)   barwidth(1) gap(10) lcolor(gray)) ///
       (histogram temp2, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(gray) lpattern(dash)) ///
       (histogram temp3, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(black)) ///
	   if ((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 ) ///
	   , legend(order(1 "Advance"  2 "Immediate" 3 "Unambiguous")row(1)) ///
	   xlabel(2 "Worse Off" 6 "Equal" 10 "Better Off") ///
	   title("Panel A:" "Offered Commitment") ///
	   scheme(s1mono)
graph save "panelA.gph", replace


/* Panel B: Mandated Advance Choice */
capture drop temp
gen temp = 5
replace temp = 9 if bundlediffidum_adv == 1 
replace temp = 1 if bundlediffidum_adv == -1  
replace temp = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)

capture drop temp2
gen temp2 = 6
replace temp2 = 10 if bundlediffidum_imm == 1 
replace temp2 = 2 if bundlediffidum_imm == -1 
replace temp2 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0& sample == 1 )


capture drop temp3
gen temp3 = 7
replace temp3 = 11 if bundlediffidum_un == 1
replace temp3 = 3 if bundlediffidum_un == -1 
replace temp3 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)



twoway (histogram temp , discrete  percent width(1) fcolor(none)   barwidth(1) gap(10) lcolor(gray)) ///
       (histogram temp2, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(gray) lpattern(dash)) ///
       (histogram temp3, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(black)) ///
	   if ((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 ) ///
	   , legend(order(1 "Advance"  2 "Immediate" 3 "Unambiguous")row(1)) ///
	   xlabel(2 "Worse Off" 6 "Equal" 10 "Better Off") ///
	   title("Panel B:" "Mandated Advance") ///
	   scheme(s1mono)
graph save "panelB.gph", replace


/* Panel C: Tailored Commitment */

capture drop temp
gen temp = 5
replace temp = 9 if bundlediffidum_adv == 1 & tailorcommit == 1
replace temp = 1 if bundlediffidum_adv == -1  & tailorcommit == 1
replace temp = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)

capture drop temp2
gen temp2 = 6
replace temp2 = 10 if bundlediffidum_imm == 1 & tailorcommit == 1
replace temp2 = 2 if bundlediffidum_imm == -1 & tailorcommit == 1
replace temp2 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0& sample == 1 )


capture drop temp3
gen temp3 = 7
replace temp3 = 11 if bundlediffidum_un == 1 & tailorcommit == 1
replace temp3 = 3 if bundlediffidum_un == -1  & tailorcommit == 1
replace temp3 = . if !((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 & sample == 1)



twoway (histogram temp , discrete  percent width(1) fcolor(none)   barwidth(1) gap(10) lcolor(gray)) ///
       (histogram temp2, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(gray) lpattern(dash)) ///
       (histogram temp3, discrete  percent  width(1) fcolor(none) barwidth(1) gap(10) lcolor(black)) ///
	   if ((obsnum ==1 | obsnum == 41)  & commitavail == 0 & attrit ==0 ) ///
	   , legend(order(1 "Advance"  2 "Immediate" 3 "Unambiguous")row(1)) ///
	   xlabel(2 "Worse Off" 6 "Equal" 10 "Better Off") ///
	   title("Panel C:" "Tailored Mandate") ///
	   scheme(s1mono)
graph save "panelC.gph", replace



grc1leg "panelA.gph" "panelB.gph" "panelC.gph" , row(1) scheme(s1mono) ycommon xsize(24) ysize(8) 
graph export "evaluationfig.pdf", replace

/*** END FIGURE 7 ***/			   
			   
/*** BEGIN APPENDIX FIGURE A.1****/
twoway  (scatter bundlecalimm bundlecaladv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlecalimm bundlecaladv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 1100 1100 7000 7000, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 1, ytitle(Imm.)  title(Calories) xtitle(Advance Calories) xlabel(1000(2000)7000) ylabel(0(0)0)  legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelA1.gph", replace  

twoway  (scatter bundlecalimm bundlecaladv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlecalimm bundlecaladv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 1100 1100 7000 7000, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 0, ytitle(Imm.) title(Calories) xtitle(Advance Calories) xlabel(1000(2000)7000)  ylabel(0(0)0)   legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelB1.gph", replace  

twoway  (scatter bundlefatimm bundlefatadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlefatimm bundlefatadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 0 0 250 250, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 1, ytitle(Imm.) xtitle(Advance Fat (gr)) title(Fat) xlabel(0(50)250) ylabel(0(0)0) legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelA2.gph", replace  

twoway  (scatter bundlefatimm bundlefatadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlefatimm bundlefatadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 0 0 250 250, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 0, ytitle(Imm.) xtitle(Advance Fat (gr)) title(Fat) xlabel(0(50)250)  ylabel(0(0)0) legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelB2.gph", replace  


twoway  (scatter bundlecarbimm bundlecarbadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlecarbimm bundlecarbadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 200 200 1200 1200, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 1, ytitle(Imm.)  xtitle(Advance Carbs (gr)) title(Carbs) xlabel(200(200)1200) ylabel(0(0)0)  legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelA3.gph", replace  


twoway  (scatter bundlecarbimm bundlecarbadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundlecarbimm bundlecarbadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 200 200 1200 1200, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 0, ytitle(Imm.)  xtitle(Advance Carbs (gr)) title(Carbs) xlabel(200(200)1200) ylabel(0(0)0)  legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelB3.gph", replace  


twoway  (scatter bundleproteinimm bundleproteinadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundleproteinimm bundleproteinadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 20 20 140 140, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 1, ytitle(Imm.)  xtitle(Advance Protein (gr)) title(Protein) xlabel(20(20)140) ylabel(0(0)0)   legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelA4.gph", replace  

  
twoway  (scatter bundleproteinimm bundleproteinadv if sample == 1 & inconsistent == 1, mcolor(black) msymbol(circle_hollow)) (scatter bundleproteinimm bundleproteinadv if sample ==1 & inconsistent == 0, mcolor(black) msymbol(plus)) (scatteri 20 20 140 140, recast(line) lcolor(black) lwidth(thin) lpattern(vshortdash)) if chicago == 0, ytitle(Imm.)  xtitle(Advance Protein (gr)) title(Protein) xlabel(20(20)140) ylabel(0(0)0)  legend(order(1 "Inconsistent" 2 "Consistent") rows(1)) scheme(s1mono)
graph save "panelB4.gph", replace  

  
grc1leg "panelA1.gph"  "panelA2.gph" "panelA3.gph"  "panelA4.gph" , row(1) scheme(s1mono) xsize(15) ysize(5) title("Panel A: Chicago")
graph save "panelAbig.gph", replace  

grc1leg "panelB1.gph"  "panelB2.gph" "panelB3.gph"  "panelB4.gph" , row(1) scheme(s1mono) xsize(15) ysize(5) title("Panel B: Los Angeles")
graph save "panelBbig.gph", replace    
  
grc1leg "panelAbig.gph" "panelBbig.gph", row(2) scheme(s1mono) xsize(15) ysize(5)
graph export "behaviorappendix.pdf", replace

/*** END APPENDIX FIGURE A.1 ***/
			   
/*** BEGIN APPENDIX FIGURE A.2 ***/


capture drop sample
gen sample = 0
replace sample = 1 if commitavail == 0 & (obsnum == 1 | obsnum == 41) & attrit == 0  &  ///
inconsistent == 1 & bundlediffiperc_adv != . & bundlediffiperc_imm != . & bundlediffiperc_un != .  & ranki_un == 4 & ranki_adv == 4 & ranki_imm == 4 



twoway (histogram bundlediffibest_imm ,  percent  width(0.5) barwidth(0.35) gap(10) color(gray) ) ///
       (histogram bundlediffibest_adv,  percent  width(0.5) fcolor(none) barwidth(0.35) gap(10) lcolor(black)) ///
	   (scatteri 0 0 30 0, recast(line) lpattern(dash) lcolor(gray)) /// 
	    if sample == 1, 	   scheme(s1mono) ///
	   legend(order(2 "Advance" 1 "Immediate"  ) row(1))   title(Panel A: Welfare Effects of Inconsistency) xtitle("Best-Food Equivalents")
graph save "panelA.gph", replace   


twoway 		(scatter bundlediffibest_imm bundlediffibest_adv, jitter(10)) ///
(lfit bundlediffibest_imm bundlediffibest_adv, lcolor(gray) lpattern(solid)) ///
(scatteri -10 -10 10 10, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri -10 0 10 0, recast(line) lpattern(dash) lcolor(gray)) /// 
(scatteri 0 -10 0 10, recast(line) lpattern(dash) lcolor(gray)) /// 
	   if sample == 1, 	   scheme(s1mono) ///
	   	xtitle(Advance) ytitle(Immediate)    legend(order(2 "Immediate-Advance Fit, Corr = 0.23 (p <0.01)"  ) row(1)) title(Panel B: Advance-Immediate Agreement) 
graph save "panelB.gph", replace  
graph combine "panelA.gph" "panelB.gph", xsize(16) ysize(8) row(1) scheme(s1mono)
graph export "graphwelfareappendix.pdf", replace

/** Additional Stats for Appendix Figure A.2 ***/
su bundlediffibest_adv bundlediffibest_imm if sample == 1, det
signrank bundlediffibest_adv =  bundlediffibest_imm  if sample == 1

/*** END APPENDIX FIGURE A.2 ***/
